@@ -2,8 +2,13 @@ import abc
 from copy import deepcopy
 from django.db.models.query import QuerySet
 from rest_framework.exceptions import ValidationError
-from common.rest_extend.response import PageTypeResults, Results, get_error_status_code, REQUEST_ERROR_CODE, \
-    RESTResponse
+from common.rest_extend.response import (
+    PageTypeResults,
+    Results,
+    get_error_status_code,
+    REQUEST_ERROR_CODE,
+    RESTResponse,
+)
 from django.db.models import Q, Count
 
 from common.utility.args_parsing import BaseArgsParsing
@@ -15,6 +20,16 @@ class Select(BaseArgsParsing, metaclass=abc.ABCMeta):
     RESERVED_FIELD = deepcopy(BaseArgsParsing.RESERVED_FIELD) + [GROUP]
     FORBID_VALUES = {GROUP: ["password"]}
 
+    def conver_bool(self, value):
+        if isinstance(value, str):
+            return value.lower() == "true"
+        if isinstance(value, int):
+            return value == 1
+
+        if isinstance(value, bool):
+            return value
+        raise ValueError(f"'value' type cannot be {type(value)}")
+
     def get_orm_q(self, data):
         """
         获取筛选条件
@@ -80,7 +95,13 @@ class Select(BaseArgsParsing, metaclass=abc.ABCMeta):
         :return:
         """
         total = len(queryset)
-        page, size = self.get_page_and_size(data)
+        all_result = self.conver_bool(data.get(self.ALL_RESULT, False))
+        if not all_result:
+            page, size = self.get_page_and_size(data)
+        else:
+            page = 1
+            size = len(queryset)
+
         start = (page - 1) * size
         end = page * size
         current_page_queryset = queryset[start:end]
@@ -178,13 +199,13 @@ class Select(BaseArgsParsing, metaclass=abc.ABCMeta):
         pass
 
 
-class BaseORM():
+class BaseORM:
     def get_data(self, request, data):
         if not data:
             data = request.data
-            if isinstance(data,dict):
-                if 'ops' in data.keys() and 'data' in data.keys():
-                    data = data.get('data')
+            if isinstance(data, dict):
+                if "ops" in data.keys() and "data" in data.keys():
+                    data = data.get("data")
         return data
 
     def get_req_args(self, request, extend_conditions):
@@ -193,7 +214,7 @@ class BaseORM():
             data = {**data, **extend_conditions}
         return data
 
-    def parsing_args_and_data(self, request, results, data, extend_conditions=None, pk='id') -> (dict, dict, str, any):
+    def parsing_args_and_data(self, request, results, data, extend_conditions=None, pk="id") -> (dict, dict, str, any):
         conditions = {}
         req_args = self.get_req_args(request, extend_conditions)
         data = self.get_data(request, data)
